==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/kombidetails_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists kombidetails_au//
create trigger kombidetails_au after update on kombidetails
  for each row 
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID, userID, username, action,
     server, section, teststep, newvalues)
  select NEW.serverID, NEW.accessID, 'kombidetails', NEW.ID,
    NEW.autokombidetailsID, NEW.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    servername, section.name, teststep.name,
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', REPLACE(REPLACE(NEW.formel, '\\', '\\\\'), '\n', '\\n'), '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv,
           if(NEW.groupautoID > OLD.groupautoID, '\nconverted to group-auto', ''),
           if(NEW.autokombidetailsID > OLD.autokombidetailsID, '\nconverted to domain-auto', ''))
  from server, section, teststep, teststepdetails, einheiten
  where NEW.TS != OLD.TS and server.ID = NEW.serverID and section.ID = NEW.sectionID
    and teststep.ID = NEW.teststepID and teststepdetails.ID = NEW.teststepdetailsID
    and einheiten.ID = einheitID;
end//


drop trigger if exists kombidetails_ai//
create trigger kombidetails_ai after insert on kombidetails
  for each row 
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID, userID, username, action,
     server, section, teststep, newvalues)
  select NEW.serverID, NEW.accessID, 'kombidetails', NEW.ID,
    NEW.autokombidetailsID, NEW.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    servername, section.name, teststep.name,
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', REPLACE(REPLACE(NEW.formel, '\\', '\\\\'), '\n', '\\n'), '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from server, section, teststep, teststepdetails, einheiten
  where server.ID = NEW.serverID and section.ID = NEW.sectionID
    and teststep.ID = NEW.teststepID and teststepdetails.ID = NEW.teststepdetailsID
    and einheiten.ID = einheitID;
end//


drop trigger if exists kombidetails_bd//
create trigger kombidetails_bd before delete on kombidetails
  for each row 
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID, userID, username, action,
     server, section, teststep, newvalues)
  select OLD.serverID, OLD.accessID, 'kombidetails', OLD.ID,
    OLD.autokombidetailsID, OLD.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    servername, section.name, teststep.name,
    coalesce(if(OLD.bemerkungen = @combidetailsremark, '', concat('remark=', REPLACE(REPLACE(@combidetailsremark, '\\', '\\\\'), '\n', '\\n'))), '')
  from server, section, teststep
  where server.ID = OLD.serverID and section.ID = OLD.sectionID
    and teststep.ID = OLD.teststepID;
end//

delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/kombidetails_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists kombidetails_au//
create trigger kombidetails_au after update on kombidetails
  for each row
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID, userID, username, action,
     server, section, teststep, newvalues)
  select serverID, accessID, 'kombidetails', kombidetails.ID,
    autokombidetailsID, groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    servername, section.name, teststep.name,
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', REPLACE(REPLACE(formel, '\\', '\\\\'), '\n', '\\n'), '\nremark=', REPLACE(REPLACE(bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', aktiv,
           if(groupautoID > OLD.groupautoID, '\nconverted to group-auto', ''),
           if(autokombidetailsID > OLD.autokombidetailsID, '\nconverted to domain-auto', ''))
  from kombidetails
  join server on server.ID = serverID
  join section on section.ID = sectionID
  join teststep on teststep.ID = teststepID
  join teststepdetails on teststepdetails.ID = teststepdetailsID
  join einheiten on einheiten.ID = einheitID
  where kombidetails.ID = NEW.ID and kombidetails.TS = NEW.TS;
end//


drop trigger if exists kombidetails_ai//
create trigger kombidetails_ai after insert on kombidetails
  for each row
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID, userID, username, action,
     server, section, teststep, newvalues)
  select NEW.serverID, NEW.accessID, 'kombidetails', NEW.ID,
    NEW.autokombidetailsID, NEW.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    servername, section.name, teststep.name,
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', REPLACE(REPLACE(NEW.formel, '\\', '\\\\'), '\n', '\\n'), '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from server, section, teststep, teststepdetails, einheiten
  where server.ID = NEW.serverID and section.ID = NEW.sectionID
    and teststep.ID = NEW.teststepID and teststepdetails.ID = NEW.teststepdetailsID
    and einheiten.ID = einheitID;
end//


drop trigger if exists kombidetails_bd//
create trigger kombidetails_bd before delete on kombidetails
  for each row
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID, userID, username, action,
     server, section, teststep, newvalues)
  select OLD.serverID, OLD.accessID, 'kombidetails', OLD.ID,
    OLD.autokombidetailsID, OLD.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    servername, section.name, teststep.name,
    coalesce(if(OLD.bemerkungen = @combidetailsremark, '', concat('remark=', REPLACE(REPLACE(@combidetailsremark, '\\', '\\\\'), '\n', '\\n'))), '')
  from server, section, teststep
  where server.ID = OLD.serverID and section.ID = OLD.sectionID
    and teststep.ID = OLD.teststepID;
end//

delimiter ;
